<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * This file keeps track of upgrades to the settings block
 *
 * Sometimes, changes between versions involve alterations to database structures
 * and other major things that may break installations.
 *
 * The upgrade function in this file will attempt to perform all the necessary
 * actions to upgrade your older installation to the current version.
 *
 * If there's something it cannot do itself, it will tell you what you need to do.
 *
 * The commands in here will all be database-neutral, using the methods of
 * database_manager class
 *
 * Please do not forget to use upgrade_set_timeout()
 * before any action that may take longer time to finish.
 *
 * @package    contrib
 * @subpackage block_mgs_timemanager
 * @copyright  2015 Michał Sternadel
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

/**
 * @global moodle_database $DB
 * @param int $oldversion
 * @param object $block
 */
function xmldb_block_mgs_timemanager_upgrade($oldversion, $block) {
	global $DB;
    $result = true;
    if ($result && $oldversion < 2015113004) {
    	$dbman = $DB->get_manager();
    	if (!$dbman->table_exists('mgs_timemanager_downloaded')) {
    		$field1 = new xmldb_field('id');
    		$field1->set_attributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, XMLDB_SEQUENCE, null, null, null);
    		$field2 = new xmldb_field('userid');
    		$field2->set_attributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, null, null, null, null, null);
    		$field3 = new xmldb_field('courseid');
    		$field3->set_attributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, null);
    		$field4 = new xmldb_field('teacherid');
    		$field4->set_attributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, null);
    		$field5 = new xmldb_field('documenttype');
    		$field5->set_attributes(XMLDB_TYPE_TEXT, 'medium', null, null, null, null, null, null);
    		$field6 = new xmldb_field('created');
    		$field6->set_attributes(XMLDB_TYPE_DATETIME, null, null, XMLDB_NOTNULL, null, null, null, null);
    		$key1 = new xmldb_key('primary');
    		$key1->set_attributes(XMLDB_KEY_PRIMARY, array('id'), null, null);
    		$key2 = new xmldb_key('foreignkey1');
    		$key2->set_attributes(XMLDB_KEY_FOREIGN, array('userid'), 'mdl_user', array('id'));
    		$key3 = new xmldb_key('foreignkey2');
    		$key3->set_attributes(XMLDB_KEY_FOREIGN, array('courseid'), 'course', array('id'));
    		$table = new xmldb_table('mgs_timemanager_downloaded');
    		$table->addField($field1);
    		$table->addField($field2);
    		$table->addField($field3);
    		$table->addField($field4);
    		$table->addField($field5);
    		$table->addField($field6);
    		$table->addKey($key1);
    		$table->addKey($key2);
    		$table->addKey($key3);
    		$result = $dbman->create_table($table);	
    	}
    	if (!$dbman->table_exists('mgs_timemanager_completed')) {
    		$field1 = new xmldb_field('id');
    		$field1->set_attributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, XMLDB_SEQUENCE, null, null, null);
    		$field2 = new xmldb_field('userid');
    		$field2->set_attributes( XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, null);
    		$field3 = new xmldb_field('courseid');
    		$field3->set_attributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, null);
    		$field4 = new xmldb_field('spent');
    		$field4->set_attributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, null);
    		$field5 = new xmldb_field('required');
    		$field5->set_attributes(XMLDB_TYPE_INTEGER, '10',  XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, null);
    		$field6 = new xmldb_field('acceptedby');
    		$field6->set_attributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, null, null, null, null, null);
    		$field7 = new xmldb_field('created');
    		$field7->set_attributes(XMLDB_TYPE_DATETIME, null, null, XMLDB_NOTNULL, null, null, null, null);
    		$field8 = new xmldb_field('modified');
    		$field8->set_attributes(XMLDB_TYPE_DATETIME, null, null, null, null, null, null, null);
    		$key1 = new xmldb_key('primary');
    		$key1->set_attributes(XMLDB_KEY_PRIMARY, array('id'), null, null);
    		$key2 = new xmldb_key('foreignkey1');
    		$key2->set_attributes(XMLDB_KEY_FOREIGN, array('userid'), 'mdl_user', array('id'));
    		$key3 = new xmldb_key('foreignkey2');
    		$key3->set_attributes(XMLDB_KEY_FOREIGN, array('courseid'), 'course', array('id'));
    		$table = new xmldb_table('mgs_timemanager_completed');
    		$table->addField($field1);
    		$table->addField($field2);
    		$table->addField($field3);
    		$table->addField($field4);
    		$table->addField($field5);
    		$table->addField($field6);
    		$table->addField($field7);
    		$table->addField($field8);
    		$table->addKey($key1);
    		$table->addKey($key2);
    		$table->addKey($key3);
    		$result = $dbman->create_table($table);
    	}
    }
        
    return true;
}
